%
%lcaNewMonitorValue
%
%  Calling Syntax
%
%[flags] = lcaNewMonitorValue(pvs, type)
%
%  Description
%
%   Check if monitored PVs need to be read, i.e, if fresh data are
%   available (e.g., due to initial connection or changes in value and/or
%   severity status). Reading the actual data must be done using
%   [1]lcaGet.
%
%  Parameters
%
%   pvs
%          Column vector (in matlab: m x 1 cell- matrix) of m strings.
%
%   type
%          (optional argument) A string specifying the data type to be
%          used for the channel access data transfer. The native type is
%          used by default. See [2]here for more information.
%
%          Note that monitors are specific to a particular data type and
%          therefore lcaNewMonitorValue will only report the status for a
%          monitor that had been established (by lcaSetMonitor) with a
%          matching type. Using the ``native'' type, which is the default,
%          for both calls satisfies this condition.
%
%   flags
%          Column vector of flag values. A value of zero indicates that no
%          new data are available - the monitored PV has not changed since
%          it was last read (i.e., the data not the flag). A value of one
%          indicates that new data are available for reading (lcaGet). A
%          negative The flag value can be negative, indicating a problem
%          e.g.,
%
%        -1:
%                no monitor established ([3]lcaSetMonitor never called for
%                this PV/data type),
%
%        -2:
%                non-existing PV (no successful CA search so far),
%
%        -3:
%                invalid type argument,
%
%        -4:
%                invalid PV argument,
%
%        -10:
%                currently no connection.
%
%  Examples
%
%lcaNewMonitorValue('PV')
%     _________________________________________________________________
%
%
%    Till Straumann 2006-04-16
%
%References
%
%   1. lcaGet.html#lcaget
%   2. lcaGet.html#typearg
%   3. lcaSetMonitor.html#lcasetmonitor
