%
%lcaSetMonitor
%
%  Calling Syntax
%
%lcaSetMonitor(pvs, nmax, type)
%
%  Description
%
%   Set a ``monitor'' on a set of PVs. Monitored PVs are automatically
%   retrieved every time their value or status changes. labCA sets an
%   internal flag when this happens. Monitors are especially useful under
%   EPICS-3.14 which supports multiple threads. EPICS-3.14 transparently
%   reads monitored PVs as needed. Older, single threaded versions of
%   EPICS require periodic calls to labCA e.g., to [1]lcaDelay, in order
%   to allow labCA to handle monitors.
%
%   Use the [2]lcaNewMonitorValue call to check monitor status (local
%   flag). If new data are available, they are retrieved using the
%   ordinary [3]lcaGet call.
%
%   Note the difference between polling and monitoring a PV in combination
%   with polling the local monitor status flag. In the first case, remote
%   data are fetched on every polling cycle whereas in the second case,
%   data are transferred only when they change. Also, in the monitored
%   case, lcaGet reads from a local buffer rather than from the network.
%
%   There is currently no possibility to selectively remove a monitor. Use
%   the [4]lcaClear call to disconnect a channel and as a side-effect,
%   remove all monitors on that channel. Future access to a cleared
%   channel simply reestablishes a connection (but no monitors).
%
%  Parameters
%
%   pvs
%          Column vector (in matlab: m x 1 cell- matrix) of m strings.
%
%   nmax
%          (optional argument) Maximum number of elements (per PV) to
%          monitor/retrieve. If set to 0 (default), all elements are
%          fetched. See [5]here for more information.
%
%   type
%          (optional argument) A string specifying the data type to be
%          used for the channel access data transfer. The native type is
%          used by default. See [6]here for more information.
%
%          The type specified for the subsequent lcaGet for retrieving the
%          data should match the monitor's data type. Otherwise, lcaGet
%          will fetch a new copy from the server instead of using the data
%          that was already transferred as a result of the monitoring.
%
%  Examples
%
%lcaSetMonitor('PV')
%// monitor 'PV'. Reduce network traffic by just have the
%// library retrieve the first 20 elements. Use DBR_SHORT
%// for transfer.
%lcaSetMonitor('PV', 20, 's')
%     _________________________________________________________________
%
%
%    Till Straumann 2006-04-16
%
%References
%
%   1. lcaDelay.html#lcadelay
%   2. lcaNewMonitorValue.html#lcanewmonitorvalue
%   3. lcaGet.html#lcaget
%   4. lcaClear.html#lcaclear
%   5. lcaGet.html#nmaxarg
%   6. lcaGet.html#typearg
