function [amp, fr, RMS] = adc_fsweep_fast(sys, freq)

pvroot=['IGPF:', sys, ':'];

Ts = 1/lcaGet([pvroot, 'RF_FREQ'])/1e6;
opts=optimset('TolX', 1e-6, 'TolFun', 1e-6, 'LargeScale', 'off');

figure(1); clf
gpib_cmd('freq', freq(1)); pause(1.5);
for k=1:length(freq)
  x = get_data(pvroot);
  if (k < length(freq))
    gpib_cmd('freq', freq(k+1));
  end
  [sol, x_fit] = sinfit(Ts, x, opts);

  amp(k) = sol(1);
  fr(k)  = sol(2);
  RMS(k) = std(x-x_fit, 1);
  subplot(211);
  plot(freq(1:k)/1e6, amp(1:k), 'o-');
  xlabel('Frequency (MHz)');
  ylabel('Amplitude (counts)');
  grid;
  subplot(212);
  plot(freq(1:k)/1e6, RMS(1:k), 'o-r');
  xlabel('Frequency (MHz)');
  ylabel('RMS (counts)');
  grid; drawnow;
end

mag = 20*log10(amp/2048);
u = find(abs(mag-mag(1))<0.5);
base = mean(mag(u));
u = find(mag < base - 3); u = u(1);
figure(2); clf
set(gca, 'fontsize', 12);
plot(freq/1e6, mag, 'o-');
xlabel('Frequency (MHz)');
ylabel('Amplitude (dBFS)');
title(sprintf('Frequency sweep, -3 dB bandwidth of %.2f GHz', freq(u)/1e9));
grid;

figure(3); clf
subplot(212);
plot(freq/1e6, RMS, 'o-r');
xlabel('Frequency (MHz)');
ylabel('RMS (counts)');
grid;
