% iGp_gd            - Acquires iGp data and attendant variables
%
% Copyright (c) 2006 Dimtel, Inc., All Rights Reserved
%
% $Id: iGp_gd.m,v 1.3 2009/02/06 00:10:45 dim Exp $
% $Date: 2009/02/06 00:10:45 $
% $Author: dim $
% $Revision: 1.3 $
% $Log: iGp_gd.m,v $
% Revision 1.3  2009/02/06 00:10:45  dim
% Sinewave fitting improvements, processing downsampling and beam current added
%
% Revision 1.2  2008/04/29 19:54:53  dim
% Transitioned from wget to urlwrite(), DCCT support, added FE/BE channels
% to saved parameters list.
%
% Revision 1.1  2007/10/28 08:23:15  dim
% Tools to include in the distribution
%
% Revision 1.1  2007/03/14 08:35:58  dim
% Matlab tools for data acquisition and testing with file-based data exchange
%
%

function [status, prm] = iGp_gd(prm)

t00 = clock;

pvnm = ['IGPF:', prm.sys, ':'];

% Read out various parameters
prm.when = now;

pvl     = {[pvnm, 'CSET0']; [pvnm, 'CSET1']};
pvl{3}  = [pvnm, 'CR256'];
pvl{4}  = [pvnm, 'DELAY'];
pvl{5}  = [pvnm, 'GDLEN'];
pvl{6}  = [pvnm, 'HOLDOFF'];
pvl{7}  = [pvnm, 'RF_FREQ'];
pvl{8}  = [pvnm, 'HARM_NUM'];
pvl{9}  = [pvnm, 'REC_DS'];
pvl{10} = [pvnm, 'PROC_DS'];
pvl{11} = [pvnm, 'FE_ATTEN'];
pvl{12} = [pvnm, 'BE_ATTEN'];
pvl{13} = [pvnm, 'FE_PHASE'];
pvl{14} = [pvnm, 'BE_PHASE'];

% If dcct field is defined, use it as beam current PV
if isfield(prm, 'dcct')
 pvl{15} = prm.dcct;
end

% Read the channels
data = lcaGet(pvl, 0);

% Parse the data
prm.coeff0     = data(1,:)/32768;
prm.coeff1     = data(2,:)/32768;
prm.Nc         = length(prm.coeff0);
prm.shift_gain = bitand(bitshift(data(3,1), -4), 7);
prm.delay      = data(4,1);
prm.setsel     = bitand(bitshift(data(3,1), -2), 1);
prm.gden       = bitand(bitshift(data(3,1), -8), 1);
prm.gdlen      = data(5,1);
prm.holdoff    = data(6,1);
prm.rf_freq    = data(7,1);
prm.ring_size  = data(8,1);
prm.ds         = data(9,1);
prm.proc_ds    = data(10,1);
prm.fe_atten   = data(11,1);
prm.be_atten   = data(12,1);
prm.fe_phase   = data(13,1);
prm.be_phase   = data(14,1);

% If beam current PV is defined above, read out the current
[N, M] = size(data);
if (N == 15)
  prm.Io = data(15,1);
else
  prm.Io = 0;
end

clear pvl;
pvl = {[pvnm, 'DESC:CSET0']; [pvnm, 'DESC:CSET1']; [pvnm, 'EXTEN']};
desc = lcaGet(pvl);

prm.cset0 = desc{1};
prm.cset1 = desc{2};
prm.exten = desc{3};

if (prm.debug)
  t01 = clock;
  disp(['Parameters acquired after ', num2str(etime(t01, t00)), ' seconds']);
end

prm.data = get_data(pvnm);

if (prm.debug)
  t02 = clock;
  disp(['Data transferred after ', num2str(etime(t02, t00)), ' seconds']);
end

prm.st = [prm.sys, '; I_0 = ', num2str(prm.Io), ' mA; ', ...
          datestr(prm.when)];


% Save gd.mat file
M = floor(length(prm.data)/prm.ring_size);
bunches(1,:) = 1:prm.ring_size;
bunches(2:M+1,:) = zeros(M, prm.ring_size);
bunches(2:M+1,:) = reshape(prm.data(1:M*prm.ring_size), prm.ring_size, M)';

bunches(1,:) = 1:prm.ring_size;

ring_size = prm.ring_size;
rf_freq = prm.rf_freq;
shift_gain = prm.shift_gain;
downsamp = prm.ds;
if (prm.gden == 1)
  damp_brkpt = round(prm.gdlen/length(prm.data)*63);
else
  damp_brkpt = 1;
end
beamCurrent = prm.Io;
turn_offsets = zeros(ring_size, 1);

[sos0, g] = tf2sos(prm.coeff0, [1 zeros(1, prm.Nc-1)]);
num0=sos0(:,1:3)';
num0(:,1)=num0(:,1)*g;
den0 = sos0(:, 5:6)';
[sos1, g] = tf2sos(prm.coeff1, [1 zeros(1, prm.Nc-1)]);
num1=sos1(:,1:3)';
num1(:,1)=num1(:,1)*g;
den1 = sos1(:, 5:6)';
if (prm.setsel == 1)
  a = num0; num0=num1; num1=a;
  a = den0; den0=den1; den1=a;
end
num2=num0; num3=num0;
num4=num0; num5=num0; num6=num0; num7=num0;
den2=den0; den3=den0;
den4=den0; den5=den0; den6=den0; den7=den0;
sections(1:8)=size(num0, 2);
sections(2) = size(num1, 2);
scope = 2;
eval(['save ', prm.tm, '/gd bunches num0 num1 num2 num3 num4 num5 ', ...
      'num6 num7 den0 den1 den2 den3 den4 den5 den6 den7 damp_brkpt ' ...
      'turn_offsets beamCurrent downsamp shift_gain rf_freq ring_size ' ...
      'sections scope']);
eval(['save ', prm.tm, '/prm prm']);

status = 1;
